@@ -201,11 +201,9 @@ static struct
   ERR (GSASL_NO_CB_TLS_UNIQUE,
        N_("Authentication failed because a tls-unique CB was not provided.")),
   ERR (GSASL_NO_SAML20_IDP_IDENTIFIER,
-       N_("Callback failed to provide SAML20 user identifier.")),
-  ERR (GSASL_NO_SAML20_REDIRECT_URL,
-       N_("Callback failed to provide SAML20 redirect URL.")),
-  ERR (GSASL_NO_OPENID20_AUTH_IDENTIFIER,
-       N_("Callback failed to provide OPENID20 authentication identifier."))
+       N_("Callback failed to provide SAML20 IdP identifier.")),
+  ERR (GSASL_NO_REDIRECT_URL,
+       N_("Callback failed to provide redirect URL."))
 };
 /* *INDENT-ON* */
 
