@@ -1,5 +1,5 @@
 /* property.c --- Callback property handling.
- * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010  Simon Josefsson
+ * Copyright (C) 2004-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -104,6 +104,22 @@ map (Gsasl_session * sctx, Gsasl_property prop)
       p = &sctx->cb_tls_unique;
       break;
 
+    case GSASL_SAML20_IDP_IDENTIFIER:
+      p = &sctx->saml20_idp_identifier;
+      break;
+
+    case GSASL_REDIRECT_URL:
+      p = &sctx->redirect_url;
+      break;
+
+    case GSASL_OPENID20_OUTCOME_DATA:
+      p = &sctx->openid20_outcome_data;
+      break;
+
+      /* If you add anything here, remember to change change
+         gsasl_finish() in xfinish.c and Gsasl_session in
+         internal.h.  */
+
     default:
       break;
     }
@@ -189,7 +205,7 @@ gsasl_property_set_raw (Gsasl_session * sctx, Gsasl_property prop,
  *
  * This function will not invoke the application callback.
  *
- * Return value: Return property value, if known, or %NULL if no value
+ * Return value: Return property value, if known, or NULL if no value
  *   known.
  *
  * Since: 0.2.0
@@ -227,7 +243,7 @@ gsasl_property_fast (Gsasl_session * sctx, Gsasl_property prop)
  * the corresponding property.  This behaviour of this function will
  * be removed when the obsolete callback interfaces are removed.
  *
- * Return value: Return data for property, or %NULL if no value known.
+ * Return value: Return data for property, or NULL if no value known.
  *
  * Since: 0.2.0
  **/
