@@ -65,8 +65,8 @@ gsasl_finish (Gsasl_session * sctx)
   free (sctx->scram_salted_password);
   free (sctx->cb_tls_unique);
   free (sctx->saml20_idp_identifier);
-  free (sctx->saml20_redirect_url);
-  free (sctx->openid20_auth_identifier);
+  free (sctx->redirect_url);
+  free (sctx->openid20_outcome_data);
   /* If you add anything here, remember to change change
      gsasl_finish() in xfinish.c and Gsasl_session in internal.h.  */
 
